<html>
<head>
  <link rel="stylesheet" href="http://pall.sigurdsson.is/css/style.css" />
</head>
<body>

    <div id="main">
        <div id="box" >
            <div class="main_body"><div class="content"><div class=wrapper><div class="main_content">
              <h1>Welcome, friend</h1>
              <table class=table border=1 style="width: 100%; border-collapse:collapse; border: 0.5px solid grey;">
                  <thead>
                      <tr>
                        <th colspan="2">About me</th>
                        <th colspan="2">About you</th>
                      </tr>
                  </thead>
                  <tbody>
                    <tr>
                        <td>Host Name</td>
                        <td>{{ my_info.host_name }}</td>
                      <td>Host Name</td>
                      <td>{{node.host_name}}</td>
                    </tr>
                    <tr>
                        <td>Distribution</td>
                        <td>{{my_info.dist}}</td>
                        <td>Token</td>
                        <td>{{ token }}</td>
                    </tr>

                    <tr>
                        <td>Nago Version</td>
                        <td>{{my_info.nago_version}}</td>
                      <td>Access</td>
                      <td>{{node.access }}</td>
                    </tr>
                    <tr>
                        <td></td>
                        <td></td>
                      <td>Address</td>
                      <td>{{ node.address }}</td>
                    </tr>
                  </tbody>
              </table>

              <h1>Loaded extensions</h1>
              <table class="table">
                  <thead>
                  <tr>
                      <th></th>
                  </tr>
                  </thead>
                  <tbody>
                  {% for extension_name, extension in extensions.items() %}
                      <tr>
                          <th>{{extension_name}}</th>
                          <td colspan="2">{{extension.shortdesc}} </td>
                      </tr>
                        {% for method_name, method in extension.methods.items() %}
                      <tr>
                          <td></td>
                          <td>
                              <a href='{{ url_for("call_method", extension_name=extension_name, method_name=method_name) }}'>
                                {{method_name}}
                              </a>
                          </td>
                          <td>{{method.description}}</td>
                      </tr>
                        {% endfor %}
                        <tr><td colspan="3"><hr></td></tr>
                  {% endfor %}
                  </tbody>
              </table>

            </div></div></div></div>
        </div>
</body>
</html>
