<html>
<head>
  <link rel="stylesheet" href="http://pall.sigurdsson.is/css/style.css" />
</head>
<body>
  <div id="main">
      <div id="box">
            <p>You need a valid security token to continue.</p>
            <form method="POST" action="/">
                <p><input type=text name="token">
                <p><input type=submit value=Login>
            </form>
       </div>
  </div>
</body>
</html>
